﻿function Get-TargetResource
{
    param
    (
    	[validateset("Present","Absent")]
	[string]$Ensure,
	
	[Parameter(Mandatory)]
        [ValidateNotNullOrEmpty()]
	[string]$Name,

	[validateset("Enabled","Disabled")]
	[string]$State
    )
    	$rule = get-netfirewallrule -name $name
	if ($rule.Enabled -eq "True") { $State = "Enabled" } else { $State = "Disabled" }
    	#Return a hash table of values
    	$getTargetResourceResult = @{Ensure = $Ensure; Name = $name; State = $State}
    
}

function Set-TargetResource
{
    param
    (
    	[validateset("Present","Absent")]
	[string]$Ensure,
	
	[Parameter(Mandatory)]
        [ValidateNotNullOrEmpty()]
	[string]$Name,

	[validateset("Enabled","Disabled")]
	[string]$State
    )
    

    	#logic
    	# if ensure is present & state is enabled - nothing
    	# if ensure is present & state is disable - enable
  	# if ensure is absent & state is enabled - disable
    	# if ensure is absent & state is disabled - nothing
    
    	#Get State
    	$rule = get-netfirewallrule -name $name
    	if ($rule.Enabled -eq "True") { $State = "Enabled" } else { $State = "Disabled" }
    
    
    	# if Ensure is present and the rule is disabled, enable it
    	# likewise, if ensure is absent and the rule is enabled, disable it
	if ($Ensure -eq "Present" -and $State -eq "Disabled") {
		#write-verbose "Enabling rule $name"
        enable-netfirewallrule -Name $name 
	} elseif ($Ensure -eq "Absent" -and $State -eq "Enabled") {
		#write-verbose "Disabling rule $name"
        	disable-netfirewallrule -Name $name 
	}
	
}

function Test-TargetResource
{
    param
    (
    	[validateset("Present","Absent")]
	[string]$Ensure,
	
	[Parameter(Mandatory)]
        [ValidateNotNullOrEmpty()]
	[string]$Name,

	[validateset("Enabled","Disabled")]
	[string]$State
    )
	#Set the default return value to true, we will set it to false if we need to
   	$testtargetresourceresult = $true
    
    	#Get State
	$rule = get-netfirewallrule -name $name
    	if ($rule.Enabled) { $State = "Enabled" } else { $State = "Disabled" }
    
    	#if rule is enabled and is supposed to be Absent, then test should return false
    	if ($rule.Enabled -eq "True" -and $ensure -eq "Absent") 
		{ $testtargetresourceresult = $false}
	
    	#likewise, if rule is disabled and is supposed to be Present, then test should return false
    	if ($rule.Enabled -eq "False" -and $ensure -eq "Present")
		{$testtargetresourceresult = $false }
    
    	return $testtargetresourceresult


}